//***********************************************************  
//     4th order RK-Method for 1st order IVP             ****
//     y'(x) = f(x,y),  y(x0) = y0,  x0 < x < xn         ****
//     NPDE-TCA  UG-Level Workshop at IMA Bhubaneshwar   ****
//     By Manas,FOSSEE,IITB                              ****   
//***********************************************************

format('e',20)
funcprot(0)    //To avoid Warning : redefining function
lower_limit_x=input("Enter lower limit of x :")
upper_limit_x=input("Enter upper limit of x :")
y0=input("Enter initial value of y :")

        function [x,y]=rk4(lower_limit_x,upper_limit_x,y0,n,function_input)
            
//Runge-Kutta methods for solving
//Fourth order differential equation dy/dx = f(x,y).
//function call:
//[x,y]=rk3kutta(lower_limit_x,upper_limit_x,y0,n,function_input)
//Inputs:
//The initial and final values of x are given by 
//lower_limit_x,upper_limit_x
//Initial y is given by y0 
//The function f(x,y) must be defined by the user and 
//it should have the name function_input 
//n - no.of sub-intervals 

for c=1:1:3
    for incr=2^(-c) 
            n=(upper_limit_x-lower_limit_x)/incr;    //step size is given by incr
            x=lower_limit_x:incr:upper_limit_x;    //x-axis vector
            y(1)=y0;    //Initial y-point
            mprintf("increment=%f\n",incr)
            mprintf("x          calculated value      actual value      error\n")
                mprintf("%f     %f\n",lower_limit_x,y0)
                mprintf("%f     %f\n",lower_limit_x+incr,y(1))
            for i=1:n    //Loop to calculate y 
                k1=incr*feval(x(i),y(i),function_input);    //Computes slope
                k2=incr*feval(x(i)+0.5*incr,y(i)+0.5*k1,function_input);    //Computes slope
                k3=incr*feval(x(i)+0.5*incr,y(i)+0.5*k2,function_input);    //Computes slope
                k4=incr*feval(x(i)+incr,y(i)+k3,function_input);    //Computes slope
                y(i+1)=y(i)+(k1+2*k2+2*k3+k4)/6;    //Calculates y
                h=(x(i+1))^(3)/3;//the actual function satisfying differential equation
                error1=abs(y(i+1)-h);
                mprintf("%12.10f     %12.10f            %12.10f         %12.10f",x(i)+incr,y(i+1),h,error1)
                mprintf("\n")
            end
            plot2d(x,y)
            xtitle("y versus x")
            xlabel('x-axis')
            ylabel('y-axis')
        end
    end
    
    endfunction
    
    disp("Enter the function_input:") 
    disp("''y1=x^2'')","deff(''[y1]=f(x,y)'',")    //Input function format
